@@ -16,7 +16,25 @@ class MessageableMixin(object):
             rather than from the authenticated user. Note that the
             authenticated user must be a moderator of the subreddit and have
             mail permissions.
-        :returns: The json response from the server.
+
+        For example, to send a private message to ``/u/spez``, try:
+
+        .. code:: python
+
+           reddit.redditor('spez').message('TEST', 'test message from PRAW')
+
+        To send a message to ``u/spez`` from the moderators of ``r/test`` try:
+
+        .. code:: python
+
+           reddit.redditor('spez').message('TEST', 'test message from r/test',
+                                           from_subreddit='test')
+
+        To send a message to the moderators of ``/r/test``, try:
+
+        .. code:: python
+
+           reddit.subreddit('test').message('TEST', 'test PM from PRAW')
 
         """
         data = {'subject': subject, 'text': message,
@@ -24,4 +42,4 @@ class MessageableMixin(object):
                     self.__class__, 'MESSAGE_PREFIX', ''), self)}
         if from_subreddit:
             data['from_sr'] = str(from_subreddit)
-        return self._reddit.post(API_PATH['compose'], data=data)
+        self._reddit.post(API_PATH['compose'], data=data)
